You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucy.apache.org by ma...@apache.org on 2011/12/21 03:53:36 UTC

[lucy-commits] svn commit: r1221575 [2/2] - in /incubator/lucy/trunk: clownfish/perl/ clownfish/perl/lib/ clownfish/perl/lib/Clownfish/ clownfish/perl/lib/Clownfish/CFC/ clownfish/perl/lib/Clownfish/CFC/Binding/ clownfish/perl/lib/Clownfish/CFC/Binding/Perl/ clownfis...

Modified: incubator/lucy/trunk/clownfish/perl/t/401-c_block.t
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/perl/t/401-c_block.t?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/perl/t/401-c_block.t (original)
+++ incubator/lucy/trunk/clownfish/perl/t/401-c_block.t Wed Dec 21 02:53:33 2011
@@ -18,19 +18,19 @@ use warnings;
 
 use Test::More tests => 5;
 
-use Clownfish::CBlock;
-use Clownfish::Parser;
+use Clownfish::CFC::CBlock;
+use Clownfish::CFC::Parser;
 
-my $parser = Clownfish::Parser->new;
+my $parser = Clownfish::CFC::Parser->new;
 
-my $block = Clownfish::CBlock->new( contents => 'int foo;' );
-isa_ok( $block, "Clownfish::CBlock" );
+my $block = Clownfish::CFC::CBlock->new( contents => 'int foo;' );
+isa_ok( $block, "Clownfish::CFC::CBlock" );
 is( $block->get_contents, 'int foo;', "get_contents" );
-eval { Clownfish::CBlock->new };
+eval { Clownfish::CFC::CBlock->new };
 like( $@, qr/contents/, "content required" );
 
 $block = $parser->parse(qq| __C__\n#define FOO_BAR 1\n__END_C__  |);
 
-isa_ok( $block, "Clownfish::CBlock" );
+isa_ok( $block, "Clownfish::CFC::CBlock" );
 is( $block->get_contents, "#define FOO_BAR 1\n", "parse embed_c" );
 

Modified: incubator/lucy/trunk/clownfish/perl/t/402-parcel.t
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/perl/t/402-parcel.t?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/perl/t/402-parcel.t (original)
+++ incubator/lucy/trunk/clownfish/perl/t/402-parcel.t Wed Dec 21 02:53:33 2011
@@ -18,12 +18,12 @@ use warnings;
 
 use Test::More tests => 7;
 
-BEGIN { use_ok('Clownfish::Parcel') }
+BEGIN { use_ok('Clownfish::CFC::Parcel') }
 
 # Register singleton.
-Clownfish::Parcel->singleton( name => 'Crustacean', cnick => 'Crust', );
+Clownfish::CFC::Parcel->singleton( name => 'Crustacean', cnick => 'Crust', );
 
-my $thing = Clownfish::Symbol->new(
+my $thing = Clownfish::CFC::Symbol->new(
     micro_sym => 'sym',
     exposure  => 'parcel',
 );
@@ -31,7 +31,7 @@ is( $thing->get_prefix, '', 'get_prefix 
 is( $thing->get_Prefix, '', 'get_Prefix with no parcel' );
 is( $thing->get_PREFIX, '', 'get_PREFIx with no parcel' );
 
-$thing = Clownfish::Symbol->new(
+$thing = Clownfish::CFC::Symbol->new(
     micro_sym => 'sym',
     parcel    => 'Crustacean',
     exposure  => 'parcel'

Modified: incubator/lucy/trunk/clownfish/perl/t/403-file.t
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/perl/t/403-file.t?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/perl/t/403-file.t (original)
+++ incubator/lucy/trunk/clownfish/perl/t/403-file.t Wed Dec 21 02:53:33 2011
@@ -18,10 +18,10 @@ use warnings;
 
 use Test::More tests => 17;
 
-use Clownfish::File;
-use Clownfish::Parser;
+use Clownfish::CFC::File;
+use Clownfish::CFC::Parser;
 
-my $parser = Clownfish::Parser->new;
+my $parser = Clownfish::CFC::Parser->new;
 
 my $parcel_declaration = "parcel Stuff;";
 my $class_content      = qq|
@@ -64,9 +64,9 @@ is( $bar->get_type->get_specifier, 'stuf
 
 my $blocks = $file->blocks;
 is( scalar @$blocks, 3, "all three blocks" );
-isa_ok( $blocks->[0], "Clownfish::Parcel" );
-isa_ok( $blocks->[1], "Clownfish::Class" );
-isa_ok( $blocks->[2], "Clownfish::CBlock" );
+isa_ok( $blocks->[0], "Clownfish::CFC::Parcel" );
+isa_ok( $blocks->[1], "Clownfish::CFC::Class" );
+isa_ok( $blocks->[2], "Clownfish::CFC::CBlock" );
 
 $file = $parser->_parse_file( $class_content, 'Stuff::Thing' );
 ($class) = @{ $file->classes };

Modified: incubator/lucy/trunk/clownfish/perl/t/500-hierarchy.t
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/perl/t/500-hierarchy.t?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/perl/t/500-hierarchy.t (original)
+++ incubator/lucy/trunk/clownfish/perl/t/500-hierarchy.t Wed Dec 21 02:53:33 2011
@@ -18,8 +18,8 @@ use warnings;
 
 use Test::More tests => 18;
 
-use Clownfish::Hierarchy;
-use Clownfish::Util qw( a_isa_b );
+use Clownfish::CFC::Hierarchy;
+use Clownfish::CFC::Util qw( a_isa_b );
 use File::Spec::Functions qw( catfile splitpath );
 use Fcntl;
 use File::Path qw( rmtree mkpath );
@@ -32,11 +32,11 @@ my %args = (
 # Clean up.
 rmtree( $args{dest} );
 
-eval { my $death = Clownfish::Hierarchy->new( %args, extra_arg => undef ) };
+eval { my $death = Clownfish::CFC::Hierarchy->new( %args, extra_arg => undef ) };
 like( $@, qr/extra_arg/, "Extra arg kills constructor" );
 
-my $hierarchy = Clownfish::Hierarchy->new(%args);
-isa_ok( $hierarchy, "Clownfish::Hierarchy" );
+my $hierarchy = Clownfish::CFC::Hierarchy->new(%args);
+isa_ok( $hierarchy, "Clownfish::CFC::Hierarchy" );
 is( $hierarchy->get_source, $args{source}, "get_source" );
 is( $hierarchy->get_dest,   $args{dest},   "get_dest" );
 
@@ -46,10 +46,10 @@ my @files = @{ $hierarchy->files };
 is( scalar @files, 3, "recursed and found all three files" );
 my %files;
 for my $file (@files) {
-    die "not a File" unless isa_ok( $file, "Clownfish::File" );
+    die "not a File" unless isa_ok( $file, "Clownfish::CFC::File" );
     ok( !$file->get_modified, "start off not modified" );
     my ($class)
-        = grep { a_isa_b( $_, "Clownfish::Class" ) } @{ $file->blocks };
+        = grep { a_isa_b( $_, "Clownfish::CFC::Class" ) } @{ $file->blocks };
     die "no class" unless $class;
     $files{ $class->get_class_name } = $file;
 }
@@ -60,7 +60,7 @@ my $util   = $files{'Animal::Util'} or d
 my $classes = $hierarchy->ordered_classes;
 is( scalar @$classes, 3, "all classes" );
 for my $class (@$classes) {
-    die "not a Class" unless isa_ok( $class, "Clownfish::Class" );
+    die "not a Class" unless isa_ok( $class, "Clownfish::CFC::Class" );
 }
 
 # Generate fake C files, with times set to one second ago.

Modified: incubator/lucy/trunk/clownfish/perl/t/600-parser.t
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/perl/t/600-parser.t?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/perl/t/600-parser.t (original)
+++ incubator/lucy/trunk/clownfish/perl/t/600-parser.t Wed Dec 21 02:53:33 2011
@@ -18,20 +18,20 @@ use warnings;
 
 use Test::More tests => 88;
 
-BEGIN { use_ok('Clownfish::Parser') }
+BEGIN { use_ok('Clownfish::CFC::Parser') }
 
-my $parser = Clownfish::Parser->new;
-isa_ok( $parser, "Clownfish::Parser" );
+my $parser = Clownfish::CFC::Parser->new;
+isa_ok( $parser, "Clownfish::CFC::Parser" );
 
 isa_ok( $parser->parse("parcel Fish;"),
-    "Clownfish::Parcel", "parcel_definition" );
+    "Clownfish::CFC::Parcel", "parcel_definition" );
 isa_ok( $parser->parse("parcel Crustacean cnick Crust;"),
-    "Clownfish::Parcel", "parcel_definition with cnick" );
+    "Clownfish::CFC::Parcel", "parcel_definition with cnick" );
 
 # Set and leave parcel.
 my $parcel = $parser->parse('parcel Crustacean cnick Crust;')
     or die "failed to process parcel_definition";
-is( ${ Clownfish::Parser->get_parcel },
+is( ${ Clownfish::CFC::Parser->get_parcel },
     $$parcel, "parcel_definition sets internal \$parcel var" );
 
 for (qw( foo _foo foo_yoo FOO Foo fOO f00 foo_foo_foo )) {
@@ -45,7 +45,7 @@ for (qw( void float uint32_t int64_t uin
 }
 
 isa_ok( $parser->parse("bool_t"),
-    "Clownfish::Type", "Charmony integer specifier bool_t" );
+    "Clownfish::CFC::Type", "Charmony integer specifier bool_t" );
 
 is( $parser->parse("$_*")->get_specifier,
     "crust_$_", "object_type_specifier $_" )
@@ -56,7 +56,7 @@ ok( $parser->parse("const char")->const,
 ok( $parser->parse("$_ int32_t foo;")->$_, "exposure_specifier $_" )
     for qw( public private parcel );
 
-isa_ok( $parser->parse($_), "Clownfish::Type", "type $_" )
+isa_ok( $parser->parse($_), "Clownfish::CFC::Type", "type $_" )
     for ( 'const char *', 'Obj*', 'i32_t', 'char[]', 'long[1]', 'i64_t[30]' );
 
 is( $parser->parse("(int32_t foo = $_)")->get_initial_values->[0],
@@ -94,7 +94,7 @@ my %param_lists = (
 );
 while ( my ( $param_list, $num_params ) = each %param_lists ) {
     my $parsed = $parser->parse($param_list);
-    isa_ok( $parsed, "Clownfish::ParamList", "param_list: $param_list" );
+    isa_ok( $parsed, "Clownfish::CFC::ParamList", "param_list: $param_list" );
 }
 ok( $parser->parse("(int foo, ...)")->variadic, "variadic param list" );
 my $param_list = $parser->parse(q|(int foo = 0xFF, char *bar ="blah")|);

Modified: incubator/lucy/trunk/clownfish/perl/typemap
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/perl/typemap?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/perl/typemap (original)
+++ incubator/lucy/trunk/clownfish/perl/typemap Wed Dec 21 02:53:33 2011
@@ -39,12 +39,12 @@ CLOWNFISH_TYPE
 	if (!SvOK($arg)) {
         $var = NULL;
     }
-	else if (sv_derived_from($arg, \"${(my $t = $type) =~ s/CFC(\w+).*/Clownfish::$1/;\$t}\")) {
+	else if (sv_derived_from($arg, \"${(my $t = $type) =~ s/CFC(\w+).*/Clownfish::CFC::$1/;\$t}\")) {
 		IV objint = SvIV((SV*)SvRV($arg));
 		$var = INT2PTR($type, objint);
 	}
     else {
-		croak(\"Not a ${(my $t = $type) =~ s/CFC(\w+).*/Clownfish::$1/;\$t}\");
+		croak(\"Not a ${(my $t = $type) =~ s/CFC(\w+).*/Clownfish::CFC::$1/;\$t}\");
 	}
 
 CLOWNFISH_BINDING_CORE
@@ -75,7 +75,7 @@ CLOWNFISH_BINDING_CORE_TYPE
 OUTPUT
 
 CLOWNFISH_TYPE
-	sv_setref_pv($arg, \"${(my $t = $type) =~ s/CFC(\w+).*/Clownfish::$1/;\$t}\", (void*)$var);
+	sv_setref_pv($arg, \"${(my $t = $type) =~ s/CFC(\w+).*/Clownfish::CFC::$1/;\$t}\", (void*)$var);
 
 CLOWNFISH_BINDING_CORE
 	sv_setref_pv($arg, \"Clownfish::CFC::Binding::Core\", (void*)$var);

Modified: incubator/lucy/trunk/clownfish/src/CFCBase.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCBase.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCBase.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCBase.h Wed Dec 21 02:53:33 2011
@@ -17,7 +17,7 @@
 #ifndef H_CFCBASE
 #define H_CFCBASE
 
-/** Clownfish::Base - Base class for all CFC objects.
+/** Clownfish::CFC::Base - Base class for all CFC objects.
  */
 
 #ifdef __cplusplus

Modified: incubator/lucy/trunk/clownfish/src/CFCBindClass.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCBindClass.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCBindClass.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCBindClass.h Wed Dec 21 02:53:33 2011
@@ -16,7 +16,7 @@
 
 /** Clownfish::CFC::Binding::Core::Class - Generate core C code for a class.
  *
- * Clownfish::Class is an abstract specification for a class.  This module
+ * Clownfish::CFC::Class is an abstract specification for a class.  This module
  * autogenerates the C code with implements that specification.
  */
 
@@ -32,7 +32,7 @@ typedef struct CFCBindClass CFCBindClass
 struct CFCClass;
 
 /**
- * @param client A Clownfish::Class.
+ * @param client A Clownfish::CFC::Class.
  */
 struct CFCBindClass*
 CFCBindClass_new(struct CFCClass *client);

Modified: incubator/lucy/trunk/clownfish/src/CFCBindCore.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCBindCore.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCBindCore.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCBindCore.c Wed Dec 21 02:53:33 2011
@@ -252,7 +252,7 @@ S_write_parcel_c(CFCBindCore *self) {
         CFCBase **blocks = CFCFile_blocks(file);
         for (int j = 0; blocks[j] != NULL; j++) {
             const char *cfc_class = CFCBase_get_cfc_class(blocks[j]);
-            if (strcmp(cfc_class, "Clownfish::Class") == 0) {
+            if (strcmp(cfc_class, "Clownfish::CFC::Class") == 0) {
                 CFCClass *klass = (CFCClass*)blocks[j];
 
                 CFCBindClass *class_binding = CFCBindClass_new(klass);

Modified: incubator/lucy/trunk/clownfish/src/CFCBindCore.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCBindCore.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCBindCore.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCBindCore.h Wed Dec 21 02:53:33 2011
@@ -15,9 +15,9 @@
  */
 
 /** Clownfish::CFC::Binding::Core - Generate core C code for a
- * Clownfish::Hierarchy.
+ * Clownfish::CFC::Hierarchy.
  *
- * A Clownfish::Hierarchy describes an abstract specifiction for a class
+ * A Clownfish::CFC::Hierarchy describes an abstract specifiction for a class
  * hierarchy; Clownfish::CFC::Binding::Core is responsible for auto-generating C
  * code which implements that specification.
  */
@@ -33,7 +33,7 @@ struct CFCHierarchy;
 
 
 /**
- * @param hierarchy A L<Clownfish::Hierarchy>.
+ * @param hierarchy A L<Clownfish::CFC::Hierarchy>.
  * @param dest The directory where C output files will be written.
  * @param header Text which will be prepended to each generated C file --
  * typically, an "autogenerated file" warning.

Modified: incubator/lucy/trunk/clownfish/src/CFCBindFile.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCBindFile.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCBindFile.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCBindFile.c Wed Dec 21 02:53:33 2011
@@ -60,10 +60,10 @@ CFCBindFile_write_h(CFCFile *file, const
     for (int i = 0; blocks[i] != NULL; i++) {
         const char *cfc_class = CFCBase_get_cfc_class(blocks[i]);
 
-        if (strcmp(cfc_class, "Clownfish::Parcel") == 0) {
+        if (strcmp(cfc_class, "Clownfish::CFC::Parcel") == 0) {
             ;
         }
-        else if (strcmp(cfc_class, "Clownfish::Class") == 0) {
+        else if (strcmp(cfc_class, "Clownfish::CFC::Class") == 0) {
             CFCBindClass *class_binding
                 = CFCBindClass_new((CFCClass*)blocks[i]);
             char *c_header = CFCBindClass_to_c_header(class_binding);
@@ -71,7 +71,7 @@ CFCBindFile_write_h(CFCFile *file, const
             FREEMEM(c_header);
             CFCBase_decref((CFCBase*)class_binding);
         }
-        else if (strcmp(cfc_class, "Clownfish::CBlock") == 0) {
+        else if (strcmp(cfc_class, "Clownfish::CFC::CBlock") == 0) {
             const char *block_contents 
                 = CFCCBlock_get_contents((CFCCBlock*)blocks[i]);
             content = CFCUtil_cat(content, block_contents, "\n", NULL);

Modified: incubator/lucy/trunk/clownfish/src/CFCBindFile.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCBindFile.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCBindFile.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCBindFile.h Wed Dec 21 02:53:33 2011
@@ -19,7 +19,7 @@
 
 /** Clownfish::CFC::Binding::Core::File - Generate core C code for a Clownfish file.
  *
- * This module is the companion to Clownfish::File, generating the C code
+ * This module is the companion to Clownfish::CFC::File, generating the C code
  * needed to implement the file's specification.
  *
  * There is a one-to-one mapping between Clownfish header files and
@@ -37,7 +37,7 @@ struct CFCFile;
 /** Generate a C header file containing all class declarations and literal C
  * blocks.
  *
- * @param file A Clownfish::File.
+ * @param file A Clownfish::CFC::File.
  * @param dest The directory under which autogenerated files are being
  * written.
  * @param header Text which will be prepended to each generated C file --

Modified: incubator/lucy/trunk/clownfish/src/CFCBindMethod.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCBindMethod.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCBindMethod.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCBindMethod.h Wed Dec 21 02:53:33 2011
@@ -16,7 +16,7 @@
 
 /** Clownfish::CFC::Binding::Core::Method - Generate core C code for a method.
  *
- * Clownfish::Method is an abstract specification; this class generates C code
+ * Clownfish::CFC::Method is an abstract specification; this class generates C code
  * which implements the specification.
  */
 
@@ -31,8 +31,8 @@ struct CFCMethod;
 struct CFCClass;
 
 /** Return C code for the static inline vtable method invocation function.
- * @param method A L<Clownfish::Method>.
- * @param class The L<Clownfish::Class> which will be invoking the method.
+ * @param method A L<Clownfish::CFC::Method>.
+ * @param class The L<Clownfish::CFC::Class> which will be invoking the method.
  * (LobsterClaw needs its own method invocation function even if the method
  * was defined in Claw.)
  */

Modified: incubator/lucy/trunk/clownfish/src/CFCCBlock.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCCBlock.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCCBlock.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCCBlock.c Wed Dec 21 02:53:33 2011
@@ -25,7 +25,7 @@ struct CFCCBlock {
 };
 
 const static CFCMeta CFCCBLOCK_META = {
-    "Clownfish::CBlock",
+    "Clownfish::CFC::CBlock",
     sizeof(CFCCBlock),
     (CFCBase_destroy_t)CFCCBlock_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCCBlock.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCCBlock.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCCBlock.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCCBlock.h Wed Dec 21 02:53:33 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/** Clownfish::CBlock - A block of embedded C code.
+/** Clownfish::CFC::CBlock - A block of embedded C code.
  *
  * CBlock exists to support embedding literal C code within Clownfish header
  * files:

Modified: incubator/lucy/trunk/clownfish/src/CFCClass.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCClass.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCClass.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCClass.c Wed Dec 21 02:53:33 2011
@@ -106,7 +106,7 @@ static void
 S_bequeath_methods(CFCClass *self);
 
 const static CFCMeta CFCCLASS_META = {
-    "Clownfish::Class",
+    "Clownfish::CFC::Class",
     sizeof(CFCClass),
     (CFCBase_destroy_t)CFCClass_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCClass.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCClass.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCClass.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCClass.h Wed Dec 21 02:53:33 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-/** Clownfish::Class - An object representing a single class definition.
+/** Clownfish::CFC::Class - An object representing a single class definition.
  *
- * Clownfish::Class objects are stored as quasi-singletons, one for each
+ * Clownfish::CFC::Class objects are stored as quasi-singletons, one for each
  * unique parcel/class_name combination.
  */
 
@@ -37,18 +37,18 @@ struct CFCVariable;
 /** Create and register a quasi-singleton.  May only be called once for each
  * unique parcel/class_name combination.
  *
- * @param parcel See Clownfish::Symbol. 
- * @param exposure See Clownfish::Symbol. 
- * @param class_name See Clownfish::Symbol. 
- * @param cnick See Clownfish::Symbol. 
+ * @param parcel See Clownfish::CFC::Symbol. 
+ * @param exposure See Clownfish::CFC::Symbol. 
+ * @param class_name See Clownfish::CFC::Symbol. 
+ * @param cnick See Clownfish::CFC::Symbol. 
  * @param micro_sym Defaults to "class".
- * @param docucomment An optional Clownfish::DocuComment attached to this class.
+ * @param docucomment An optional Clownfish::CFC::DocuComment attached to this class.
  * @param source_class - The name of the class that owns the file in which
  * this class was declared.  Should be "Foo" if "Foo::FooJr" is defined in
  * <code>Foo.cfh</code>.
  * @param parent_class_name - The name of this class's parent class.  Needed
  * in order to establish the class hierarchy.
- * @param docucomment A Clownfish::DocuComment describing this Class.
+ * @param docucomment A Clownfish::CFC::DocuComment describing this Class.
  * @param is_inert Should be true if the class is inert, i.e. cannot be
  * instantiated.
  * @param is_final Should be true if the class is final.
@@ -73,7 +73,7 @@ CFCClass_destroy(CFCClass *self);
 
 /** Retrieve a Class, if one has already been created.
  *
- * @param A Clownfish::Parcel.
+ * @param A Clownfish::CFC::Parcel.
  * @param class_name The name of the Class.
  */
 CFCClass*

Modified: incubator/lucy/trunk/clownfish/src/CFCDocuComment.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCDocuComment.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCDocuComment.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCDocuComment.c Wed Dec 21 02:53:33 2011
@@ -79,7 +79,7 @@ S_strip(char *comment) {
 }
 
 const static CFCMeta CFCDOCUCOMMENT_META = {
-    "Clownfish::DocuComment",
+    "Clownfish::CFC::DocuComment",
     sizeof(CFCDocuComment),
     (CFCBase_destroy_t)CFCDocuComment_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCDocuComment.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCDocuComment.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCDocuComment.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCDocuComment.h Wed Dec 21 02:53:33 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/** Clownfish::DocuComment - Formatted comment a la Doxygen.
+/** Clownfish::CFC::DocuComment - Formatted comment a la Doxygen.
  */
 
 #ifndef H_CFCDOCUCOMMENT

Modified: incubator/lucy/trunk/clownfish/src/CFCDumpable.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCDumpable.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCDumpable.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCDumpable.h Wed Dec 21 02:53:33 2011
@@ -14,10 +14,10 @@
  * limitations under the License.
  */
 
-/** Clownfish::Dumpable - Auto-generate code for "dumpable" classes.
+/** Clownfish::CFC::Dumpable - Auto-generate code for "dumpable" classes.
  *
  * If a class declares that it has the attribute "dumpable", but does not
- * declare either Dump or Load(), Clownfish::Dumpable will attempt to
+ * declare either Dump or Load(), Clownfish::CFC::Dumpable will attempt to
  * auto-generate those methods if methods inherited from the parent class do
  * not suffice.
  * 

Modified: incubator/lucy/trunk/clownfish/src/CFCFile.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCFile.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCFile.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCFile.c Wed Dec 21 02:53:33 2011
@@ -42,7 +42,7 @@ struct CFCFile {
 };
 
 const static CFCMeta CFCFILE_META = {
-    "Clownfish::File",
+    "Clownfish::CFC::File",
     sizeof(CFCFile),
     (CFCBase_destroy_t)CFCFile_destroy
 };
@@ -127,7 +127,7 @@ CFCFile_add_block(CFCFile *self, CFCBase
     const char *cfc_class = CFCBase_get_cfc_class(block);
 
     // Add to classes array if the block is a CFCClass.
-    if (strcmp(cfc_class, "Clownfish::Class") == 0) {
+    if (strcmp(cfc_class, "Clownfish::CFC::Class") == 0) {
         size_t num_class_blocks = 0;
         while (self->classes[num_class_blocks] != NULL) {
             num_class_blocks++;
@@ -141,9 +141,9 @@ CFCFile_add_block(CFCFile *self, CFCBase
     }
 
     // Add to blocks array.
-    if (strcmp(cfc_class, "Clownfish::Class") == 0
-        || strcmp(cfc_class, "Clownfish::Parcel") == 0
-        || strcmp(cfc_class, "Clownfish::CBlock") == 0
+    if (strcmp(cfc_class, "Clownfish::CFC::Class") == 0
+        || strcmp(cfc_class, "Clownfish::CFC::Parcel") == 0
+        || strcmp(cfc_class, "Clownfish::CFC::CBlock") == 0
        ) {
         size_t num_blocks = 0;
         while (self->blocks[num_blocks] != NULL) {

Modified: incubator/lucy/trunk/clownfish/src/CFCFile.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCFile.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCFile.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCFile.h Wed Dec 21 02:53:33 2011
@@ -15,7 +15,7 @@
  */
 
 
-/** Clownfish::File - Structured representation of the contents of a Clownfish
+/** Clownfish::CFC::File - Structured representation of the contents of a Clownfish
  * source file.
  * 
  * An abstraction representing a file which contains Clownfish code.
@@ -48,7 +48,7 @@ void
 CFCFile_destroy(CFCFile *self);
 
 /** Add an element to the blocks array.  The block must be either a
- * Clownfish::Class, a Clownfish::Parcel, or a Clownfish::CBlock.
+ * Clownfish::CFC::Class, a Clownfish::CFC::Parcel, or a Clownfish::CFC::CBlock.
  */
 void
 CFCFile_add_block(CFCFile *self, CFCBase *block);
@@ -83,7 +83,7 @@ CFCFile_cfh_path(CFCFile *self, char *bu
 struct CFCBase**
 CFCFile_blocks(CFCFile *self);
 
-/** Return all Clownfish::Class blocks from the file as an array.
+/** Return all Clownfish::CFC::Class blocks from the file as an array.
  */
 struct CFCClass**
 CFCFile_classes(CFCFile *self);

Modified: incubator/lucy/trunk/clownfish/src/CFCFunction.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCFunction.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCFunction.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCFunction.c Wed Dec 21 02:53:33 2011
@@ -31,7 +31,7 @@
 #include "CFCUtil.h"
 
 const static CFCMeta CFCFUNCTION_META = {
-    "Clownfish::Function",
+    "Clownfish::CFC::Function",
     sizeof(CFCFunction),
     (CFCBase_destroy_t)CFCFunction_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCFunction.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCFunction.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCFunction.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCFunction.h Wed Dec 21 02:53:33 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/** Clownfish::Function - Metadata describing a function.
+/** Clownfish::CFC::Function - Metadata describing a function.
  */
 
 #ifndef H_CFCFUNCTION
@@ -43,18 +43,18 @@ struct CFCFunction {
 #endif
 
 /**
- * @param parcel A Clownfish::Parcel.
- * @param exposure The function's exposure (see L<Clownfish::Symbol>).
+ * @param parcel A Clownfish::CFC::Parcel.
+ * @param exposure The function's exposure (see L<Clownfish::CFC::Symbol>).
  * @param class_name The full name of the class in whose namespace the
  * function resides.
  * @param class_cnick The C nickname for the class. 
  * @param micro_sym The lower case name of the function, without any
  * namespacing prefixes.
- * @param return_type A Clownfish::Type representing the function's
+ * @param return_type A Clownfish::CFC::Type representing the function's
  * return type.
- * @param param_list A Clownfish::ParamList representing the
+ * @param param_list A Clownfish::CFC::ParamList representing the
  * function's argument list.
- * @param docucomment A Clownfish::DocuComment describing the
+ * @param docucomment A Clownfish::CFC::DocuComment describing the
  * function.
  * @param is_inline Should be true if the function should be inlined by the
  * compiler.

Modified: incubator/lucy/trunk/clownfish/src/CFCHierarchy.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCHierarchy.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCHierarchy.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCHierarchy.c Wed Dec 21 02:53:33 2011
@@ -63,7 +63,7 @@ static int
 S_do_propagate_modified(CFCHierarchy *self, CFCClass *klass, int modified);
 
 const static CFCMeta CFCHIERARCHY_META = {
-    "Clownfish::Hierarchy",
+    "Clownfish::CFC::Hierarchy",
     sizeof(CFCHierarchy),
     (CFCBase_destroy_t)CFCHierarchy_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCHierarchy.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCHierarchy.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCHierarchy.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCHierarchy.h Wed Dec 21 02:53:33 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-/** Clownfish::Hierarchy - A class hierarchy.
+/** Clownfish::CFC::Hierarchy - A class hierarchy.
  *
- * A Clownfish::Hierarchy consists of all the classes defined in files within
+ * A Clownfish::CFC::Hierarchy consists of all the classes defined in files within
  * a source directory and its subdirectories.
  *
  * There may be more than one tree within the Hierarchy, since all "inert"

Modified: incubator/lucy/trunk/clownfish/src/CFCMethod.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCMethod.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCMethod.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCMethod.c Wed Dec 21 02:53:33 2011
@@ -49,7 +49,7 @@ static void
 S_update_typedefs(CFCMethod *self, const char *short_sym);
 
 const static CFCMeta CFCMETHOD_META = {
-    "Clownfish::Method",
+    "Clownfish::CFC::Method",
     sizeof(CFCMethod),
     (CFCBase_destroy_t)CFCMethod_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCMethod.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCMethod.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCMethod.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCMethod.h Wed Dec 21 02:53:33 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-/** Clownfish::Method - Metadata describing an instance method.
+/** Clownfish::CFC::Method - Metadata describing an instance method.
  *
- * Clownfish::Method is a specialized subclass of Clownfish::Function, with
+ * Clownfish::CFC::Method is a specialized subclass of Clownfish::CFC::Function, with
  * the first argument required to be an Obj.
  *
  * When compiling Clownfish code to C, Method objects generate all the code
@@ -38,17 +38,17 @@ struct CFCParamList;
 struct CFCDocuComment;
 
 /**
- * @param parcel See Clownfish::Function.
- * @param exposure See Clownfish::Function.  Defaults to "parcel" if not
+ * @param parcel See Clownfish::CFC::Function.
+ * @param exposure See Clownfish::CFC::Function.  Defaults to "parcel" if not
  * supplied.
- * @param class_name See Clownfish::Function.
- * @param class_cnick See Clownfish::Function.
+ * @param class_name See Clownfish::CFC::Function.
+ * @param class_cnick See Clownfish::CFC::Function.
  * @param macro_sym - The mixed case name which will be used when invoking the
  * method.
- * @param return_type See Clownfish::Function.
- * @param param_list - A Clownfish::ParamList.  The first element must be an
+ * @param return_type See Clownfish::CFC::Function.
+ * @param param_list - A Clownfish::CFC::ParamList.  The first element must be an
  * object of the class identified by C<class_name>.
- * @param docucomment see Clownfish::Function.  May be NULL.
+ * @param docucomment see Clownfish::CFC::Function.  May be NULL.
  * @param is_final - Indicate whether the method is final.
  * @param is_abstract - Indicate whether the method is abstract.
  */
@@ -176,7 +176,7 @@ CFCMethod_abstract(CFCMethod *self);
 int
 CFCMethod_novel(CFCMethod *self);
 
-/** Return the Clownfish::Type for <code>self</code>.
+/** Return the Clownfish::CFC::Type for <code>self</code>.
  */
 
 struct CFCType*

Modified: incubator/lucy/trunk/clownfish/src/CFCParamList.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCParamList.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCParamList.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCParamList.c Wed Dec 21 02:53:33 2011
@@ -38,7 +38,7 @@ static void
 S_generate_c_strings(CFCParamList *self);
 
 const static CFCMeta CFCPARAMLIST_META = {
-    "Clownfish::ParamList",
+    "Clownfish::CFC::ParamList",
     sizeof(CFCParamList),
     (CFCBase_destroy_t)CFCParamList_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCParamList.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCParamList.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCParamList.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCParamList.h Wed Dec 21 02:53:33 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/** Clownfish::ParamList - parameter list.
+/** Clownfish::CFC::ParamList - parameter list.
  */
 
 #ifndef H_CFCPARAMLIST
@@ -41,7 +41,7 @@ CFCParamList_destroy(CFCParamList *self)
 
 /** Add a parameter to the ParamList.
  * 
- * @param variable A Clownfish::Variable.
+ * @param variable A Clownfish::CFC::Variable.
  * @param value The parameter's default value, which should be NULL
  * if there is no default and thus the parameter is required.
  */

Modified: incubator/lucy/trunk/clownfish/src/CFCParcel.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCParcel.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCParcel.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCParcel.c Wed Dec 21 02:53:33 2011
@@ -100,7 +100,7 @@ S_validate_name_or_cnick(const char *ori
 }
 
 const static CFCMeta CFCPARCEL_META = {
-    "Clownfish::Parcel",
+    "Clownfish::CFC::Parcel",
     sizeof(CFCParcel),
     (CFCBase_destroy_t)CFCParcel_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCParcel.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCParcel.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCParcel.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCParcel.h Wed Dec 21 02:53:33 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/** Clownfish::Parcel - Collection of code.
+/** Clownfish::CFC::Parcel - Collection of code.
  *
  * A Parcel is a cohesive collection of code, which could, in theory, be
  * published as as a single entity.
@@ -24,7 +24,7 @@
  * 
  *     prefix_ClassNick_local_symbol
  * 
- * Clownfish::Parcel supports the first tier, specifying initial prefixes.
+ * Clownfish::CFC::Parcel supports the first tier, specifying initial prefixes.
  * These prefixes come in three capitalization variants: prefix_, Prefix_, and
  * PREFIX_.
  */
@@ -70,7 +70,7 @@ CFCParcel_default_parcel(void);
 
 /** Return the Parcel under which Obj, CharBuf, VArray, Hash, etc. live.  At
  * some point in the future, these core object types may move to the
- * "Clownfish" Parcel, but for now they are within "Lucy".
+ * "Clownfish" CFC" Parcel, but for now they are within "Lucy".
  */
 CFCParcel*
 CFCParcel_clownfish_parcel(void);

Modified: incubator/lucy/trunk/clownfish/src/CFCParseHeader.y
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCParseHeader.y?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCParseHeader.y (original)
+++ incubator/lucy/trunk/clownfish/src/CFCParseHeader.y Wed Dec 21 02:53:33 2011
@@ -397,7 +397,7 @@ class_defs(A) ::= class_defs(B) var_decl
 class_defs(A) ::= class_defs(B) subroutine_declaration_statement(C).
 {
     A = B;
-    if (strcmp(CFCBase_get_cfc_class(C), "Clownfish::Function") == 0) {
+    if (strcmp(CFCBase_get_cfc_class(C), "Clownfish::CFC::Function") == 0) {
         CFCClass_add_function(A, (CFCFunction*)C);
     }
     else {

Modified: incubator/lucy/trunk/clownfish/src/CFCParser.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCParser.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCParser.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCParser.c Wed Dec 21 02:53:33 2011
@@ -44,7 +44,7 @@ struct CFCParser {
 };
 
 const static CFCMeta CFCPARSER_META = {
-    "Clownfish::Parser",
+    "Clownfish::CFC::Parser",
     sizeof(CFCParser),
     (CFCBase_destroy_t)CFCParser_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCParser.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCParser.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCParser.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCParser.h Wed Dec 21 02:53:33 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-/** Clownfish::Parser - Parse Clownfish header files.
+/** Clownfish::CFC::Parser - Parse Clownfish header files.
  *
- * Clownfish::Parser is a combined lexer/parser which parses Clownfish header
+ * Clownfish::CFC::Parser is a combined lexer/parser which parses Clownfish header
  * files.  It is not at all strict, as it relies heavily on the C parser to
  * pick up errors such as misspelled type names.  
  */

Modified: incubator/lucy/trunk/clownfish/src/CFCSymbol.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCSymbol.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCSymbol.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCSymbol.c Wed Dec 21 02:53:33 2011
@@ -28,7 +28,7 @@
 #include "CFCUtil.h"
 
 const static CFCMeta CFCSYMBOL_META = {
-    "Clownfish::Symbol",
+    "Clownfish::CFC::Symbol",
     sizeof(CFCSymbol),
     (CFCBase_destroy_t)CFCSymbol_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCSymbol.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCSymbol.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCSymbol.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCSymbol.h Wed Dec 21 02:53:33 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-/** Clownfish::Symbol - Base class for Clownfish symbols.
+/** Clownfish::CFC::Symbol - Base class for Clownfish symbols.
  *
- * Clownfish::Symbol serves as a parent class for entities which may live in
+ * Clownfish::CFC::Symbol serves as a parent class for entities which may live in
  * the global namespace, such as classes, functions, methods, and variables.
  */
 
@@ -53,7 +53,7 @@ int
 CFCSymbol_validate_class_name_component(const char *name);
 
 /**
- * @param parcel A Clownfish::Parcel.  If not supplied, will be assigned to the
+ * @param parcel A Clownfish::CFC::Parcel.  If not supplied, will be assigned to the
  * default Parcel.
  * @param exposure The scope in which the symbol is exposed.  Must be
  * 'public', 'parcel', 'private', or 'local'.

Modified: incubator/lucy/trunk/clownfish/src/CFCType.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCType.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCType.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCType.c Wed Dec 21 02:53:33 2011
@@ -44,7 +44,7 @@ struct CFCType {
 };
 
 const static CFCMeta CFCTYPE_META = {
-    "Clownfish::Type",
+    "Clownfish::CFC::Type",
     sizeof(CFCType),
     (CFCBase_destroy_t)CFCType_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCType.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCType.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCType.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCType.h Wed Dec 21 02:53:33 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-/** Clownfish::Type - A variable's type.
+/** Clownfish::CFC::Type - A variable's type.
  */
 
 #ifndef H_CFCTYPE
@@ -45,7 +45,7 @@ struct CFCParcel;
  * 
  * @param flags Flags which apply to the Type.  Supplying incompatible flags
  * will trigger an error.
- * @param parcel A Clownfish::Parcel.
+ * @param parcel A Clownfish::CFC::Parcel.
  * @param specifier The C name for the type, not including any indirection or
  * array subscripts.  
  * @param indirection integer indicating level of indirection. Example: the C
@@ -109,8 +109,8 @@ CFCType_new_float(int flags, const char 
  *
  * @param flags Allowed flags: OBJECT, STRING_TYPE, CONST, NULLABLE,
  * INCREMENTED, DECREMENTED.
- * @param parcel A Clownfish::Parcel.
- * @param specifier Required.  Must follow the rules for Clownfish::Class
+ * @param parcel A Clownfish::CFC::Parcel.
+ * @param specifier Required.  Must follow the rules for Clownfish::CFC::Class
  * class name components.
  * @param indirection Level of indirection.  Must be 1 if supplied.
  */
@@ -122,7 +122,7 @@ CFCType_new_object(int flags, struct CFC
  * single, uniform subtype.
  *
  * @param flags Allowed flags: COMPOSITE, NULLABLE
- * @param child The Clownfish::Type which the composite is comprised of.
+ * @param child The Clownfish::CFC::Type which the composite is comprised of.
  * @param indirection integer indicating level of indirection. Example: the C type
  * "float**" has indirection 2.
  * @param array A string describing an array postfix.  
@@ -131,7 +131,7 @@ CFCType*
 CFCType_new_composite(int flags, CFCType *child, int indirection,
                       const char *array);
 
-/** Return a Clownfish::Type representing a the 'void' keyword in C.  It can
+/** Return a Clownfish::CFC::Type representing a the 'void' keyword in C.  It can
  * be used either for a void return type, or in conjuction with with
  * new_composite() to support the <code>void*</code> opaque pointer type.
  *
@@ -167,7 +167,7 @@ CFCType_new_va_list(void);
  *    Lobster_foo_t -> crust_Lobster_foo_t  # prefix prepended
  *
  * @param specifier The name of the type, which must end in "_t".
- * @param parcel A Clownfish::Parcel.
+ * @param parcel A Clownfish::CFC::Parcel.
  */
 CFCType*
 CFCType_new_arbitrary(struct CFCParcel *parcel, const char *specifier);
@@ -175,7 +175,7 @@ CFCType_new_arbitrary(struct CFCParcel *
 void
 CFCType_destroy(CFCType *self);
 
-/** Returns true if two Clownfish::Type objects are equivalent.
+/** Returns true if two Clownfish::CFC::Type objects are equivalent.
  */
 int
 CFCType_equals(CFCType *self, CFCType *other);

Modified: incubator/lucy/trunk/clownfish/src/CFCUtil.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCUtil.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCUtil.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCUtil.h Wed Dec 21 02:53:33 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-/** Clownfish::Util - Miscellaneous helper functions.
+/** Clownfish::CFC::Util - Miscellaneous helper functions.
  *
- * Clownfish::Util provides a few convenience functions used internally by
+ * Clownfish::CFC::Util provides a few convenience functions used internally by
  * other Clownfish modules.
  */
 

Modified: incubator/lucy/trunk/clownfish/src/CFCVariable.c
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCVariable.c?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCVariable.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCVariable.c Wed Dec 21 02:53:33 2011
@@ -39,7 +39,7 @@ struct CFCVariable {
 };
 
 const static CFCMeta CFCVARIABLE_META = {
-    "Clownfish::Variable",
+    "Clownfish::CFC::Variable",
     sizeof(CFCVariable),
     (CFCBase_destroy_t)CFCVariable_destroy
 };

Modified: incubator/lucy/trunk/clownfish/src/CFCVariable.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCVariable.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/clownfish/src/CFCVariable.h (original)
+++ incubator/lucy/trunk/clownfish/src/CFCVariable.h Wed Dec 21 02:53:33 2011
@@ -17,9 +17,9 @@
 #ifndef H_CFCVARIABLE
 #define H_CFCVARIABLE
 
-/** Clownfish::Variable - A Clownfish variable.
+/** Clownfish::CFC::Variable - A Clownfish variable.
  *
- * A variable, having a L<Type|Clownfish::Type>, a micro_sym (i.e. name), an
+ * A variable, having a L<Type|Clownfish::CFC::Type>, a micro_sym (i.e. name), an
  * exposure, and optionally, a location in the global namespace hierarchy.
  *
  * Variable objects which exist only within a local scope, e.g. those within
@@ -37,11 +37,11 @@ struct CFCParcel;
 struct CFCType;
 
 /** 
- * @param type A Clownfish::Type.
+ * @param type A Clownfish::CFC::Type.
  * @param micro_sym The variable's name, without any namespacing prefixes.
- * @param exposure See Clownfish::Symbol.
- * @param class_name See Clownfish::Symbol.
- * @param class_cnick See Clownfish::Symbol.
+ * @param exposure See Clownfish::CFC::Symbol.
+ * @param class_name See Clownfish::CFC::Symbol.
+ * @param class_cnick See Clownfish::CFC::Symbol.
  */
 CFCVariable*
 CFCVariable_new(struct CFCParcel *parcel, const char *exposure,

Modified: incubator/lucy/trunk/perl/buildlib/Lucy/Build.pm
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/perl/buildlib/Lucy/Build.pm?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================
--- incubator/lucy/trunk/perl/buildlib/Lucy/Build.pm (original)
+++ incubator/lucy/trunk/perl/buildlib/Lucy/Build.pm Wed Dec 21 02:53:33 2011
@@ -215,12 +215,12 @@ sub ACTION_lemon {
 sub _compile_clownfish {
     my $self = shift;
 
-    require Clownfish::Hierarchy;
+    require Clownfish::CFC::Hierarchy;
     require Clownfish::CFC::Binding::Perl;
     require Clownfish::CFC::Binding::Perl::Class;
 
     # Compile Clownfish.
-    my $hierarchy = Clownfish::Hierarchy->new(
+    my $hierarchy = Clownfish::CFC::Hierarchy->new(
         source => $CORE_SOURCE_DIR,
         dest   => $AUTOGEN_DIR,
     );
--- incubator/lucy/trunk/clownfish/src/CFCDumpable.c (original)
+++ incubator/lucy/trunk/clownfish/src/CFCDumpable.c Wed Dec 21 02:53:33 2011
@@ -43,7 +43,7 @@ S_add_dump_method(CFCClass *klass);
 static void
 S_add_load_method(CFCClass *klass);
 
 // Create a Clownfish::Method object for either Dump() or Load().
 static CFCMethod*
 S_make_method_obj(CFCClass *klass, const char *method_name);
 
@@ -62,7 +62,7 @@ struct CFCDumpable {
 };
 
 const static CFCMeta CFCDUMPABLE_META = {
-    "Clownfish::Dumpable",
+    "Clownfish::CFC::Dumpable",
     sizeof(CFCDumpable),
     (CFCBase_destroy_t)CFCDumpable_destroy
 };
@@ -43,7 +43,7 @@ S_add_dump_method(CFCClass *klass);
 S_add_load_method(CFCClass *klass);
 
-// Create a Clownfish::Method object for either Dump() or Load().
+// Create a Clownfish::CFC::Method object for either Dump() or Load().
 static CFCMethod*
 S_make_method_obj(CFCClass *klass, const char *method_name);

Modified: incubator/lucy/trunk/clownfish/src/CFCDumpable.h
URL: http://svn.apache.org/viewvc/incubator/lucy/trunk/clownfish/src/CFCDumpable.h?rev=1221575&r1=1221574&r2=1221575&view=diff
==============================================================================